@@ -31,6 +31,7 @@ import shutil
 import sys
 
 import ly.pkginfo
+from . import setvar
 
 
 def usage():
@@ -70,6 +71,7 @@ class Options(object):
         self.replace_pattern = True
         self.backup_suffix = '~'
         self.with_filename = None
+        self.default_language = "nederlands"
         
         self.indent_width = 2
         self.indent_tabs = False
@@ -81,12 +83,14 @@ class Options(object):
     
     def set_variable(self, name, value):
         name = name.replace('-', '_')
-        if value.lower() in ('yes', 'on', 'true'):
-            value = True
-        elif value.lower() in ('no', 'off', 'false'):
-            value = False
-        elif value.isdigit():
-            value = int(value)
+        try:
+            func = getattr(setvar, name)
+        except AttributeError:
+            die("unknown variable: {name}".format(name=name))
+        try:
+            value = func(value)
+        except ValueError as e:
+            die(format(e))
         setattr(self, name, value)
     
 class Output(object):
@@ -200,6 +204,9 @@ def parse_command_line():
             opts.encoding = next_arg("missing encoding name")
         elif arg == '--output-encoding':
             opts.output_encoding = next_arg("missing output encoding name")
+        elif arg in ('-l', '--language'):
+            s = next_arg("missing language name")
+            opts.set_variable("default-language", s)
         elif arg == '--':
             files.extend(args)
         elif arg.startswith('-'):
