@@ -329,25 +329,54 @@ class Mediator():
     def set_relative(self, note):
         self.prev_pitch = note.pitch
 
-    def new_note(self, note, rel=False):
+    def new_note(self, note, rel=False, is_unpitched=False):
         self.current_is_rest = False
         self.clear_chord()
-        self.current_note = self.create_barnote_from_note(note)
-        self.current_lynote = note
-        self.check_current_note(rel)
+        if is_unpitched:
+            self.current_note = self.create_unpitched(note)
+            self.check_current_note(is_unpitched=True)
+        else:
+            self.current_note = self.create_barnote_from_note(note)
+            self.current_lynote = note
+            self.check_current_note(rel)
         self.do_action_onnext(self.current_note)
         self.action_onnext = None
 
+    def new_iso_dura(self, note, rel=False, is_unpitched=False):
+        """
+        Isolated durations in music sequences.
+
+        An isolated duration in LilyPond is rendered as a normal note but the
+        pitch information is missing and has to be filled in by some other
+        means, usually by the previous pitch. (RhythmicStaff is an exception
+        since it ignores specified pitches anyway).
+
+        """
+        if self.current_chord:
+            self.copy_prev_chord(note.duration)
+        else:
+            if not is_unpitched:
+                note.pitch = self.current_lynote.pitch
+            self.new_note(note, rel, is_unpitched)
+
+    def create_unpitched(self, unpitched):
+        """Create a xml_objs.Unpitched from ly.music.items.Unpitched."""
+        dura = unpitched.duration
+        return xml_objs.Unpitched(dura)
+
     def create_barnote_from_note(self, note):
         """Create a xml_objs.BarNote from ly.music.items.Note."""
         p = getNoteName(note.pitch.note)
         alt = get_xml_alter(note.pitch.alter)
-        acc = note.accidental_token
+        try:
+            acc = note.accidental_token
+        except AttributeError:
+            acc = ""
         dura = note.duration
         return xml_objs.BarNote(p, alt, acc, dura, self.voice)
 
     def copy_barnote_basics(self, bar_note):
-        """Create a xml_objs.BarNote from ly.music.items.Note."""
+        """Create a copy of a xml_objs.BarNote."""
         p = bar_note.base_note
         alt = bar_note.alter
         acc = bar_note.accidental_token
@@ -363,10 +392,11 @@ class Mediator():
         self.dur_tokens = tokens
         self.check_duration(self.current_is_rest)
 
-    def check_current_note(self, rel=False, rest=False):
+    def check_current_note(self, rel=False, rest=False, is_unpitched=False):
         """ Perform checks common for all new notes and rests. """
-        if not rest: #don't do this for rests
+        if not rest and not is_unpitched:
             self.set_octave(rel)
+        if not rest:
             if self.tied:
                 self.current_note.set_tie('stop')
                 self.tied = False
