@@ -29,6 +29,7 @@ is captured.
 from __future__ import unicode_literals
 from __future__ import print_function
 
+import ly.document
 import ly.music
 
 from . import create_musicxml
@@ -56,6 +57,9 @@ class End():
     def __init__(self, node):
         self.node = node
 
+    def __repr__(self):
+        return '<{0} {1}>'.format(self.__class__.__name__, self.node)
+
 
 class ParseSource():
     """ creates the XML-file from the source code according to the Music XML standard """
@@ -80,8 +84,29 @@ class ParseSource():
         self.tremolo = False
         self.tupl_span = False
         self.unset_tuplspan = False
+        self.alt_mode = None
+        self.rel_pitch_isset = False
+
+    def parse_text(self, ly_text):
+        """Parse the LilyPond source as text."""
+        doc = ly.document.Document(ly_text)
+        self.parse_document(doc)
+
+    def parse_document(self, ly_doc):
+        """Parse the LilyPond source as a ly.document document.
+
+        The document is converted to absolute mode to facilitate the export.
+        Use parse_text instead if you want the document to be unaffected.
+
+        """
+        import ly.pitch.rel2abs
+        cursor = ly.document.Cursor(ly_doc)
+        ly.pitch.rel2abs.rel2abs(cursor)
+        mustree = ly.music.document(ly_doc)
+        self.parse_tree(mustree)
 
     def parse_tree(self, mustree):
+        """Parse the LilyPond source as a ly.music node tree."""
         # print(mustree.dump())
         header_nodes = self.iter_header(mustree)
         if header_nodes:
@@ -166,12 +191,16 @@ class ParseSource():
     def Context(self, context):
         r""" \context """
         self.in_context = True
-        if context.context() in pno_contexts:
+        self.check_context(context.context(), context.context_id(), context.token)
+
+    def check_context(self, context, context_id=None, token=""):
+        """Check context and do appropriate action (e.g. create new part)."""
+        if context in pno_contexts:
             self.mediator.new_part(piano=True)
             self.piano_staff = 1
-        elif context.context() in group_contexts:
+        elif context in group_contexts:
             self.mediator.new_group()
-        elif context.context() in staff_contexts:
+        elif context in staff_contexts:
             if self.piano_staff:
                 if self.piano_staff > 1:
                     self.mediator.set_voicenr(nr=self.piano_staff+3)
@@ -180,17 +209,17 @@ class ParseSource():
                 self.piano_staff += 1
             else:
                 # Check first if part already exists
-                if context.token != '\\context' or self.mediator.part_not_empty():
+                if token != '\\context' or self.mediator.part_not_empty():
                     self.mediator.new_part()
-            self.mediator.add_staff_id(context.context_id())
-        elif context.context() == 'Voice':
+            self.mediator.add_staff_id(context_id)
+        elif context == 'Voice':
             self.sims_and_seqs.append('voice')
-            if context.context_id():
-                self.mediator.new_section(context.context_id())
+            if context_id:
+                self.mediator.new_section(context_id)
             else:
                 self.mediator.new_section('voice')
         else:
-            print("Context not implemented:", context.context())
+            print("Context not implemented:", context)
 
     def VoiceSeparator(self, voice_sep):
         self.mediator.new_snippet('sim')
@@ -213,30 +242,55 @@ class ParseSource():
         self.mediator.new_key(key.pitch().output(), key.mode())
 
     def Relative(self, relative):
-        pass
+        r"""A \relative music expression."""
+        self.relative = True
 
     def Note(self, note):
         """ notename, e.g. c, cis, a bes ... """
         #print(note.token)
         if note.length():
-            self.mediator.new_note(note, self.relative)
-            if self.tuplet:
-                self.mediator.change_to_tuplet(self.fraction, self.ttype)
-                self.ttype = ""
-            if self.grace_seq:
-                self.mediator.new_grace()
-            if self.trem_rep and not self.look_ahead(note, ly.music.items.Duration):
-                self.mediator.set_tremolo(trem_type='start', repeats=self.trem_rep)
+            if self.relative and not self.rel_pitch_isset:
+                self.mediator.new_note(note, False)
+                self.mediator.set_relative(note)
+                self.rel_pitch_isset = True
+            else:
+                self.mediator.new_note(note, self.relative)
+            self.check_note(note)
         else:
             if isinstance(note.parent(), ly.music.items.Relative):
                 self.mediator.set_relative(note)
-                self.relative = True
+                self.rel_pitch_isset = True
             elif isinstance(note.parent(), ly.music.items.Chord):
                 self.mediator.new_chord(note, note.parent().duration, self.relative)
                 # chord as grace note
                 if self.grace_seq:
                     self.mediator.new_chord_grace()
 
+    def Unpitched(self, unpitched):
+        """A note without pitch, just a standalone duration."""
+        if unpitched.length():
+            if self.alt_mode == 'drum':
+                self.mediator.new_iso_dura(unpitched, self.relative, True)
+            else:
+                self.mediator.new_iso_dura(unpitched, self.relative)
+            self.check_note(unpitched)
+
+    def DrumNote(self, drumnote):
+        """A note in DrumMode."""
+        if drumnote.length():
+            self.mediator.new_note(drumnote, is_unpitched=True)
+            self.check_note(drumnote)
+
+    def check_note(self, note):
+        """Generic check for all notes, both pitched and unpitched."""
+        if self.tuplet:
+            self.mediator.change_to_tuplet(self.fraction, self.ttype)
+            self.ttype = ""
+        if self.grace_seq:
+            self.mediator.new_grace()
+        if self.trem_rep and not self.look_ahead(note, ly.music.items.Duration):
+            self.mediator.set_tremolo(trem_type='start', repeats=self.trem_rep)
+
     def Duration(self, duration):
         """A written duration"""
         if self.tempo:
@@ -414,9 +468,31 @@ class ParseSource():
         """Another lyric item (skip, extender, hyphen or tie)."""
         self.mediator.new_lyrics_item(lyrics_item.token)
 
-    def LyricMode(self, lyric_mode):
+    def NoteMode(self, notemode):
+        r"""A \notemode or \notes expression."""
+        self.alt_mode = 'note'
+
+    def ChordMode(self, chordmode):
+        r"""A \chordmode or \chords expression."""
+        self.alt_mode = 'chord'
+
+    def DrumMode(self, drummode):
+        r"""A \drummode or \drums expression.
+
+        If the shorthand form \drums is found, DrumStaff is implicit.
+
+        """
+        if drummode.token == '\\drums':
+            self.check_context('DrumStaff')
+        self.alt_mode = 'drum'
+
+    def FigureMode(self, figmode):
+        r"""A \figuremode or \figures expression."""
+        self.alt_mode = 'figure'
+
+    def LyricMode(self, lyricmode):
         r"""A \lyricmode, \lyrics or \addlyrics expression."""
-        pass
+        self.alt_mode = 'lyric'
 
     def Override(self, override):
         r"""An \override command."""
@@ -502,6 +578,11 @@ class ParseSource():
             self.sims_and_seqs.pop()
         elif end.node.token == '\\with':
             self.with_contxt = None
+        elif end.node.token == '\\drums':
+            self.mediator.check_part()
+        elif isinstance(end.node, ly.music.items.Relative):
+            self.relative = False
+            self.rel_pitch_isset = False
         else:
             # print("end:", end.node.token)
             pass
@@ -557,8 +638,8 @@ class ParseSource():
                 yield n
                 for c in self.iter_score(n, doc):
                     yield c
-        if isinstance(scorenode, ly.music.items.Container):
-            yield End(scorenode)
+                if isinstance(s, ly.music.items.Container):
+                    yield End(s)
 
     def unfold_repeat(self, repeat_node, repeat_count, doc):
         r"""
