@@ -167,9 +167,13 @@ class IterateXmlObjs():
     def new_xml_note(self, obj):
         """Create note specific xml-nodes."""
         divdur = self.count_duration(obj.duration, self.divisions)
-        self.musxml.new_note(obj.base_note, obj.octave, obj.type, divdur,
-            obj.alter, obj.accidental_token, obj.voice, obj.dot, obj.chord,
-            obj.grace)
+        if isinstance(obj, Unpitched):
+            self.musxml.new_unpitched_note(obj.base_note, obj.octave, obj.type, divdur,
+                obj.voice, obj.dot, obj.chord, obj.grace)
+        else:
+            self.musxml.new_note(obj.base_note, obj.octave, obj.type, divdur,
+                obj.alter, obj.accidental_token, obj.voice, obj.dot, obj.chord,
+                obj.grace)
         for t in obj.tie:
             self.musxml.tie_note(t)
         for s in obj.slur:
@@ -189,7 +193,7 @@ class IterateXmlObjs():
         if obj.lyric:
             for l in obj.lyric:
                 try:
-                   self.musxml.add_lyric(l[0], l[1], l[2], l[3])
+                    self.musxml.add_lyric(l[0], l[1], l[2], l[3])
                 except IndexError:
                     self.musxml.add_lyric(l[0], l[1], l[2])
 
@@ -422,7 +426,7 @@ class Bar():
             new_voice.obj_list.pop(0)
         try:
             if self.obj_list[-1].barline and new_voice.obj_list[-1].barline:
-               self.obj_list.pop()
+                self.obj_list.pop()
         except AttributeError:
             pass
         if not new_voice.is_skip():
@@ -536,7 +540,7 @@ class BarNote(BarMus):
         self.octave = octave
 
     def set_tie(self, tie_type):
-        self.tie.append(tie_type);
+        self.tie.append(tie_type)
 
     def set_slur(self, slur_type):
         self.slur.append(slur_type)
@@ -579,6 +583,15 @@ class BarNote(BarMus):
         self.lyric[index][2] = nr
 
 
+class Unpitched(BarNote):
+    """Object to keep track of unpitched notes."""
+    def __init__(self, duration, step=None, voice=1):
+        BarNote.__init__(self, 'B', 0, "", duration, voice=1)
+        self.octave = 4
+        if step:
+            self.base_note = step.upper()
+
+
 class BarRest(BarMus):
     """ object to keep track of different rests and skips """
     def __init__(self, duration, voice=1, show_type=True, skip=False, pos=0):
